@@ -1,4 +1,4 @@
-"Emp.variog" <-
+Emp.variog <-
 function(day,obs,forecast,id,coord1,coord2,cut.points=NULL,max.dist=NULL,nbins=300){
 # default values
 if(missing(cut.points))
@@ -228,3 +228,4 @@ for(i in 1:l.day){
    B <- list(mar.var=round(gop.var,3),bin.midpoints=fin.x.vec,number.pairs=fin.n.h,empir.variog=fin.avg.variog)
    return(B)
 }
+
